@@ -47,9 +47,9 @@ static void pe_tracevar(pe_watcher *wa, SV *sv, int got) {
     queueEvent((pe_event*) ev);
 }
 
-static I32 tracevar_r(IV ix, SV *sv)
+static I32 tracevar_r(pTHX_ IV ix, SV *sv)
 { pe_tracevar((pe_watcher *)ix, sv, PE_R); return 0; /*ignored*/ }
-static I32 tracevar_w(IV ix, SV *sv)
+static I32 tracevar_w(pTHX_ IV ix, SV *sv)
 { pe_tracevar((pe_watcher *)ix, sv, PE_W); return 0; /*ignored*/ }
 
 static char *pe_var_start(pe_watcher *_ev, int repeat) {
